@@ -204,8 +204,12 @@ def show_sets_filter(response):
 
         cur_set['fullRoundText'] = node['fullRoundText']
 
-        cur_set['bracketName'] = node['phaseGroup']['phase']['name']
-        cur_set['bracketId'] = node['phaseGroup']['id']
+        if node['phaseGroup'] is not None:
+            cur_set['bracketName'] = node['phaseGroup']['phase']['name']
+            cur_set['bracketId'] = node['phaseGroup']['id']
+        else:
+            cur_set['bracketName'] = None
+            cur_set['bracketId'] = None
 
         # This gives player_ids, but it also is made to work with team events
         for j in range(0, 2):
